summaryrefslogtreecommitdiff
path: root/libcli
diff options
context:
space:
mode:
authorOlly Betts <olly@survex.com>2018-11-28 11:10:17 +1300
committerDouglas Bagnall <dbagnall@samba.org>2018-11-30 03:35:13 +0100
commit28aeb86a9fbc102007e3152bc6c574232204803a (patch)
tree7ca94e7f74c1bd0c5d25b31f9f26d14b7ba65ed1 /libcli
parent669249ae93bd492559b25539830773af3fa5cca7 (diff)
downloadsamba-28aeb86a9fbc102007e3152bc6c574232204803a.tar.gz
Fix spelling mistakes
Signed-off-by: Olly Betts <olly@survex.com> Reviewed-by: Douglas Bagnall <douglas.bagnall@catalyst.net.nz> Reviewed-by: Andrew Bartlett <abartlet@samba.org>
Diffstat (limited to 'libcli')
-rw-r--r--libcli/util/tstream.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libcli/util/tstream.h b/libcli/util/tstream.h
index 36ae65d9e5b..3bf80f0e925 100644
--- a/libcli/util/tstream.h
+++ b/libcli/util/tstream.h
@@ -51,7 +51,7 @@ typedef NTSTATUS tstream_read_pdu_blob_full_fn_t(void *private_data,
*
* @param[in] stream The stream to read data from.
*
* @param[in] inital_read_size The initial byte count that is needed to workout
* the full pdu size.
*
* @param[in] full_fn The callback function that will report the size
@@ -69,7 +69,7 @@ typedef NTSTATUS tstream_read_pdu_blob_full_fn_t(void *private_data,
struct tevent_req *tstream_read_pdu_blob_send(TALLOC_CTX *mem_ctx,
struct tevent_context *ev,
struct tstream_context *stream,
- size_t inital_read_size,
+ size_t initial_read_size,
tstream_read_pdu_blob_full_fn_t *full_fn,
void *full_private);
/**
@@ -51,7 +51,7 @@ typedef NTSTATUS tstream_read_pdu_blob_full_fn_t(void *private_data,
* @param[in] stream The stream to read data from.
*
- * @param[in] inital_read_size The initial byte count that is needed to workout
+ * @param[in] initial_read_size The initial byte count that is needed to workout
* the full pdu size.
*